@@ -368,6 +368,17 @@ where
     type Target = Fortify<T::Target>;
 }
 
+impl<T: Iterator> Iterator for Fortify<T>
+where
+    for<'a> T: Lower<'a>,
+    for<'a> <T as Lower<'a>>::Target: Iterator<Item = T::Item>,
+{
+    type Item = T::Item;
+    fn next(&mut self) -> Option<Self::Item> {
+        self.with_mut(|inner| inner.next())
+    }
+}
+
 impl<T> Drop for Fortify<T> {
     fn drop(&mut self) {
         unsafe {
